@@ -43,8 +43,9 @@ class Request(object):
     _query = None
     _cookies = None
 
-    #: WSGI key for the session variable
-    SESSION_ENV_KEY = 'fresco.session'
+    #: WSGI key for the session variable. The default value is configured for
+    #: use with `beaker <http://beaker.groovie.org/>`_
+    SESSION_ENV_KEY = 'beaker.session'
 
     #: The WSGI environ dict
     environ = None
